@@ -1,3 +1,4 @@
+from pybi.core.components.reactiveComponent.echarts import EChartJsCode
 from .app import App
 
 # import pybi.core.styles as styles
@@ -20,6 +21,7 @@ __all__ = [
     "app",
     "styles",
     "easy_echarts",
+    "echartJsCode",
     "to_json",
     "sql",
     "set_dataView",
@@ -43,6 +45,7 @@ add_table = app.add_table
 add_echart = app.add_echart
 colBox = app.colBox
 flowBox = app.flowBox
+echartJsCode = EChartJsCode
 box = app.box
 to_json = app.to_json
 set_dataView = app.set_dataView
